#!/system/bin/sh

MODDIR=${0%/*}

LCD_BRIGHTNESS_FILE=/sys/class/leds/lcd-backlight/brightness
LED1_FILE=/sys/class/leds/mt6370_pmu_led1/brightness
LED2_FILE=/sys/class/leds/mt6370_pmu_led2/brightness
LED_MAX_BRIGHTNESS=6

# Set this to "true" to always turn off the keypad backlight
ALWAYS_OFF=true

# Function to turn off LEDs
turn_off_leds() {
    for i in {1..5}; do
        echo 0 > $LED1_FILE
        echo 0 > $LED2_FILE
        sleep 0.1
    done
}

# Function to set LED brightness
set_led_brightness() {
    local brightness=$1
    echo "$brightness" > $LED1_FILE
    echo "$brightness" > $LED2_FILE
}

# Main logic
if [ "$ALWAYS_OFF" = true ]; then
    # Always turn off keypad lights
    turn_off_leds
else
    # Check screen brightness
    LCD_VALUE=$(cat $LCD_BRIGHTNESS_FILE)

    if [ "$LCD_VALUE" -eq 0 ]; then
        # Screen off: turn off the lights
        turn_off_leds
    else
        # Screen on: Adjust based on light sensor
        LIGHT_SENSOR_VALUE=$(dumpsys sensorservice | grep "LIGHT: last 50 events" -A 50 | tail -n 1 | awk '{gsub(/.00,/, "", $(NF-2)); print $(NF-2)}')

        if [ -z "$LIGHT_SENSOR_VALUE" ]; then
            # If no sensor value, set max brightness
            set_led_brightness $LED_MAX_BRIGHTNESS
        elif (( $(echo "$LIGHT_SENSOR_VALUE < 100" | bc -l) )); then
            # Low light: set max brightness
            set_led_brightness $LED_MAX_BRIGHTNESS
        else
            # High light: turn off LEDs
            turn_off_leds
        fi
    fi
fi

exit 0
